@@ -1,7 +1,7 @@
 /*
- * @(#) $Id: tiff.c 267 2015-07-04 21:54:44Z leres $ (XSE)
+ * @(#) $Id: tiff.c 287 2017-01-21 19:15:36Z leres $ (XSE)
  *
- * Copyright (c) 1999, 2000, 2008, 2009, 2010, 2015
+ * Copyright (c) 1999, 2000, 2008, 2009, 2010, 2015, 2017
  *	Craig Leres
  *
  * Redistribution and use in source and binary forms, with or without
@@ -16,6 +16,7 @@
  */
 
 #include <sys/types.h>
+#include <sys/stat.h>
 
 #include <stdio.h>
 #include <tiffio.h>
@@ -28,19 +29,18 @@
 #include "tiff.h"
 
 int
-parsetiff(const char *tiff, int *wp, int *hp)
+parsetiff(const char *tiff, int *wp, int *hp, struct timespec *mtimp)
 {
 	TIFF *t;
+	struct stat sbuf;
 
 	t = TIFFOpen(tiff, "r");
 	if (t == NULL)
 		return (0);
 
-#ifdef notdef
 	/* XXX ignore errors */
-	if (tp != NULL && fstat(TIFFFileno(t), &sbuf) >= 0)
-		*tp = sbuf.st_mtime;
-#endif
+	if (mtimp != NULL && fstat(TIFFFileno(t), &sbuf) >= 0)
+		*mtimp = sbuf.st_mtim;
 
 	(void)TIFFGetField(t, TIFFTAG_IMAGEWIDTH, wp);
 	(void)TIFFGetField(t, TIFFTAG_IMAGELENGTH, hp);
