@@ -1,5 +1,5 @@
 #!/bin/sh
-# @(#) $Id: updatetimestamps.sh 321 2023-01-14 21:31:06Z leres $ (XSE)
+# @(#) $Id: updatetimestamps.sh 333 2023-09-25 20:36:01Z leres $ (XSE)
 #
 # updatetimestamps - image the timestamps section of a webindex.conf file
 #
@@ -63,7 +63,7 @@ gentimestamps()
 	ls ${d} | awk '
 	BEGIN {
 	}
-	/\.(jpg|JPG|png|PNG|gif|GIF|mov|MOV|mp3|mpg|mp4|MPG|tif|TIF)$/ {
+	/\.(jpg|JPG|png|PNG|gif|GIF|mov|MOV|mp3|mpg|mp4|MPG|tif|TIF|txt|TXT)$/ {
 		if ($0 ~ /"/) {
 			# Silently skip
 			next
