@@ -1,5 +1,5 @@
 /*
- * @(#) $Id: webindex.c 341 2023-10-06 21:02:44Z leres $ (XSE)
+ * @(#) $Id: webindex.c 345 2023-10-10 19:56:04Z leres $ (XSE)
  *
  * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2013, 2015, 2016, 2017, 2018, 2019, 2022, 2023
  *	Craig Leres
@@ -103,18 +103,12 @@ struct webfile {
 
 /* Globals */
 const char *prog;
-int debug;
 int fflag;
 int recurse;
-int verbose;
-int errors;
 int killed;				/* child was killed */
-char affix[2048];
-char prefix[2048];
 char *reason;
 
 const char defindexfn[] = "index.html";
-const char *configfn = "webindex.conf";
 const char defdatefmt[] = "%l:%M%p";
 
 extern char *optarg;
@@ -192,7 +186,6 @@ char *findsection(struct webfile *, struct cf *);
 void header(FILE *, struct cf *);
 void hookupthumbnails(struct cf *, struct webfile *, int);
 int invisible(const char *, struct cf *, int);
-int isdot(const char *);
 int isthumbfn(const char *);
 int main(int, char **);
 void parsethumbnail(struct cf *, struct webfile *);
@@ -1542,12 +1535,6 @@ checkmode(const char *fn, mode_t mode, int wtype)
 		    prog, affix, prefix, fn, mode & 0777);
 }
 
-int
-isdot(const char *dn)
-{
-	return (strcmp(".", dn) == 0 || strcmp("./", dn) == 0);
-}
-
 int
 isthumbfn(const char *fn)
 {
@@ -1694,86 +1681,6 @@ naildir(struct cf *cf)
 	return (".nai");
 }
 
-/* pushd/pop that tracks the current prefix (if endp is not NULL) */
-int
-pushd(const char *dname, char **endp, int *dp)
-{
-	const char *p;
-
-	/* Remember end of the prefix string */
-	if (endp != NULL)
-		*endp = prefix + strlen(prefix);
-
-	if (isdot(dname)) {
-		*dp = -1;
-		if (debug > 1)
-			fprintf(stderr, "%s: pushd noop \"%s%s\" (%d)\n",
-			    prog, affix, prefix, *dp);
-		return (1);
-	}
-
-	/* Remember our current working directory */
-	*dp = open(".", O_RDONLY);
-	if (*dp < 0) {
-		fprintf(stderr,
-		    "%s: pushd: open: Can't open directory %s%s: %s\n",
-		    prog, affix, prefix, strerror(errno));
-		++errors;
-		return (0);
-	}
-
-	/* Change directory */
-	if (chdir(dname) < 0) {
-		fprintf(stderr, "%s: pushd: chdir %s%s%s: %s\n",
-		    prog, affix, prefix, dname, strerror(errno));
-		(void)close(*dp);
-		*dp = -1;
-		++errors;
-		return (0);
-	}
-
-	if (endp != NULL) {
-		/* Appended current directory to prefix */
-		strlcat(prefix, dname, sizeof(prefix));
-
-		/* Now that we know it's a directory, insure trailing slash */
-		p = dname + strlen(dname) - 1;
-		if (p >= dname && *p != '/')
-			strlcat(prefix, "/", sizeof(prefix));
-	}
-
-	if (debug > 1)
-		fprintf(stderr, "%s: pushd \"%s%s\" (%d)\n",
-		    prog, affix, prefix, *dp);
-	return (1);
-}
-
-int
-popd(char *endp, int d)
-{
-	int ret;
-
-	ret = 0;
-	/* Truncate anything we may have appended to the prefix */
-	if (endp != NULL)
-		*endp = '\0';
-
-	/* Restore current working directory */
-	if (d >= 0) {
-		if (fchdir(d) < 0) {
-			fprintf(stderr, "%s: popd: fchdir %s: %s\n", prog,
-			    *prefix != '\0' ? prefix : ".", strerror(errno));
-			++errors;
-			ret = 1;
-		}
-		(void)close(d);
-	}
-	if (debug > 1)
-		fprintf(stderr, "%s: popd \"%s%s\" (%d)\n",
-		    prog, affix, prefix, d);
-	return (ret);
-}
-
 /*
  * Find the section that goes with this filename.
  * The section data is removed from the list and freed.
@@ -1807,7 +1714,7 @@ void
 usage(void)
 {
 	fprintf(stderr, "%s version %s\n", prog, version);
-	fprintf(stderr, "usage: %s [-dfrv] [-c CONF] [directory ...]\n", prog);
+	fprintf(stderr, "usage: %s [-dfrv] [-c conf] [directory ...]\n", prog);
 	if (verbose)
 		fprintf(stderr, "%s", copyright);
 	exit(1);
